#
# This file is part of the Chemical Data Processing Toolkit
#
# Copyright (C) Thomas Seidel <thomas.seidel@univie.ac.at>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; see the file COPYING. If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

##
# \brief Provides constants for the specification of <em>Universal Force Field (UFF)</em> atom types.
# 
# \see [\ref UFF]
# 
class UFFAtomType(Boost.Python.instance):

    ##
    # \brief Atom with no matching UFF atom type.
    # 
    NONE = 0

    ##
    # \brief 
    #
    H   = 1

    ##
    # \brief Hydrogen bridging between two boron atoms.
    # 
    H_b = 2

    ##
    # \brief 
    #
    He_4_4 = 3

    ##
    # \brief 
    #
    Li = 4

    ##
    # \brief 
    #
    Be_3_2 = 5

    ##
    # \brief 
    #
    B_3 = 6

    ##
    # \brief 
    #
    B_2 = 7

    ##
    # \brief 
    #
    C_3 = 8

    ##
    # \brief 
    #
    C_R = 9

    ##
    # \brief 
    #
    C_2 = 10

    ##
    # \brief 
    #
    C_1 = 11

    ##
    # \brief 
    #
    N_3 = 12

    ##
    # \brief 
    #
    N_R = 13

    ##
    # \brief 
    #
    N_2 = 14

    ##
    # \brief 
    #
    N_1 = 15

    ##
    # \brief 
    #
    O_3 = 16

    ##
    # \brief Oxygen in a zeolite framework.
    # 
    O_3_z = 17

    ##
    # \brief 
    #
    O_R = 18

    ##
    # \brief 
    #
    O_2 = 19

    ##
    # \brief 
    #
    O_1 = 20

    ##
    # \brief 
    #
    F = 21

    ##
    # \brief 
    #
    Ne_4_4 = 22

    ##
    # \brief 
    #
    Na = 23

    ##
    # \brief 
    #
    Mg_3_2 = 24

    ##
    # \brief 
    #
    Al_3 = 25

    ##
    # \brief 
    #
    Si_3 = 26

    ##
    # \brief 
    #
    P_3_3 = 27

    ##
    # \brief 
    #
    P_3_5 = 28

    ##
    # \brief 
    #
    P_3_q = 29

    ##
    # \brief 
    #
    S_3_2 = 30

    ##
    # \brief 
    #
    S_3_4 = 31

    ##
    # \brief 
    #
    S_3_6 = 32

    ##
    # \brief 
    #
    S_R = 33

    ##
    # \brief 
    #
    S_2 = 34

    ##
    # \brief 
    #
    Cl = 35

    ##
    # \brief 
    #
    Ar_4_4 = 36

    ##
    # \brief 
    #
    K = 37

    ##
    # \brief 
    #
    Ca_6_2 = 38

    ##
    # \brief 
    #
    Sc_3_3 = 39

    ##
    # \brief 
    #
    Ti_3_4 = 40

    ##
    # \brief 
    #
    Ti_6_4 = 41

    ##
    # \brief 
    #
    V_3_5 = 42

    ##
    # \brief 
    #
    Cr_6_3 = 43

    ##
    # \brief 
    #
    Mn_6_2 = 44

    ##
    # \brief 
    #
    Fe_3_2 = 45

    ##
    # \brief 
    #
    Fe_6_2 = 46

    ##
    # \brief 
    #
    Co_6_3 = 47

    ##
    # \brief 
    #
    Ni_4_2 = 48

    ##
    # \brief 
    #
    Cu_3_1 = 49

    ##
    # \brief 
    #
    Zn_3_2 = 50

    ##
    # \brief 
    #
    Ga_3_3 = 51

    ##
    # \brief 
    #
    Ge_3 = 52

    ##
    # \brief 
    #
    As_3_3 = 53

    ##
    # \brief 
    #
    Se_3_2 = 54

    ##
    # \brief 
    #
    Br = 55

    ##
    # \brief 
    #
    Kr_4_4 = 56

    ##
    # \brief 
    #
    Rb = 57

    ##
    # \brief 
    #
    Sr_6_2 = 58

    ##
    # \brief 
    #
    Y_3_3 = 59

    ##
    # \brief 
    #
    Zr_3_4 = 60

    ##
    # \brief 
    #
    Nb_3_5 = 61

    ##
    # \brief 
    #
    Mo_6_6 = 62

    ##
    # \brief 
    #
    Mo_3_6 = 63

    ##
    # \brief 
    #
    Tc_6_5 = 64

    ##
    # \brief 
    #
    Ru_6_2 = 65

    ##
    # \brief 
    #
    Rh_6_3 = 66

    ##
    # \brief 
    #
    Pd_4_2 = 67

    ##
    # \brief 
    #
    Ag_1_1 = 68

    ##
    # \brief 
    #
    Cd_3_2 = 69

    ##
    # \brief 
    #
    In_3_3 = 70

    ##
    # \brief 
    #
    Sn_3 = 71

    ##
    # \brief 
    #
    Sb_3_3 = 72

    ##
    # \brief 
    #
    Te_3_2 = 73

    ##
    # \brief 
    #
    I = 74

    ##
    # \brief 
    #
    Xe_4_4 = 75

    ##
    # \brief 
    #
    Cs = 76

    ##
    # \brief 
    #
    Ba_6_2 = 77

    ##
    # \brief 
    #
    La_3_3 = 78

    ##
    # \brief 
    #
    Ce_6_3 = 79

    ##
    # \brief 
    #
    Pr_6_3 = 80

    ##
    # \brief 
    #
    Nd_6_3 = 81

    ##
    # \brief 
    #
    Pm_6_3 = 82

    ##
    # \brief 
    #
    Sm_6_3 = 83

    ##
    # \brief 
    #
    Eu_6_3 = 84

    ##
    # \brief 
    #
    Gd_6_3 = 85

    ##
    # \brief 
    #
    Tb_6_3 = 86

    ##
    # \brief 
    #
    Dy_6_3 = 87

    ##
    # \brief 
    #
    Ho_6_3 = 88

    ##
    # \brief 
    #
    Er_6_3 = 89

    ##
    # \brief 
    #
    Tm_6_3 = 90

    ##
    # \brief 
    #
    Yb_6_3 = 91

    ##
    # \brief 
    #
    Lu_6_3 = 92

    ##
    # \brief 
    #
    Hf_3_4 = 93

    ##
    # \brief 
    #
    Ta_3_5 = 94

    ##
    # \brief 
    #
    W_6_6 = 95

    ##
    # \brief 
    #
    W_3_4 = 96

    ##
    # \brief 
    #
    W_3_6 = 97

    ##
    # \brief 
    #
    Re_6_5 = 98

    ##
    # \brief 
    #
    Re_3_7 = 99

    ##
    # \brief 
    #
    Os_6_6 = 100

    ##
    # \brief 
    #
    Ir_6_3 = 101

    ##
    # \brief 
    #
    Pt_4_2 = 102

    ##
    # \brief 
    #
    Au_4_3 = 103

    ##
    # \brief 
    #
    Hg_1_2 = 104

    ##
    # \brief 
    #
    Tl_3_3 = 105

    ##
    # \brief 
    #
    Pb_3 = 106

    ##
    # \brief 
    #
    Bi_3_3 = 107

    ##
    # \brief 
    #
    Po_3_2 = 108

    ##
    # \brief 
    #
    At = 109

    ##
    # \brief 
    #
    Rn_4_4 = 110

    ##
    # \brief 
    #
    Fr = 111

    ##
    # \brief 
    #
    Ra_6_2 = 112

    ##
    # \brief 
    #
    Ac_6_3 = 113

    ##
    # \brief 
    #
    Th_6_4 = 114

    ##
    # \brief 
    #
    Pa_6_4 = 115

    ##
    # \brief 
    #
    U_6_4 = 116

    ##
    # \brief 
    #
    Np_6_4 = 117

    ##
    # \brief 
    #
    Pu_6_4 = 118

    ##
    # \brief 
    #
    Am_6_4 = 119

    ##
    # \brief 
    #
    Cm_6_3 = 120

    ##
    # \brief 
    #
    Bk_6_3 = 121

    ##
    # \brief 
    #
    Cf_6_3 = 122

    ##
    # \brief 
    #
    Es_6_3 = 123

    ##
    # \brief 
    #
    Fm_6_3 = 124

    ##
    # \brief 
    #
    Md_6_3 = 125

    ##
    # \brief 
    #
    No_6_3 = 126

    ##
    # \brief 
    #
    Lr_6_3 = 127

    ##
    # \brief 
    #
    MAX_TYPE = 127
