/* 
 * CDFRegularGridDataWriter.hpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef CDPL_GRID_CDFREGULARGRIDDATAWRITER_HPP
#define CDPL_GRID_CDFREGULARGRIDDATAWRITER_HPP

#include <iosfwd>

#include "CDPL/Grid/CDFDataWriter.hpp"
#include "CDPL/Grid/RegularGrid.hpp"
#include "CDPL/Internal/ByteBuffer.hpp"


namespace CDPL
{

    namespace Base
    {

        class ControlParameterContainer;
    }

    namespace Grid
    {

        class CDFRegularGridDataWriter : protected CDFDataWriter
        {

          public:
            CDFRegularGridDataWriter(const Base::ControlParameterContainer& ctrl_params):
                ctrlParams(ctrl_params) {}

            bool writeGrid(std::ostream& os, const DRegularGrid& grid);

            void writeGrid(const DRegularGrid& grid, Internal::ByteBuffer& bbuf);

          protected:
            void appendGrid(const DRegularGrid& grid, Internal::ByteBuffer& bbuf);

            void outputGridData(const DRegularGrid& grid, Internal::ByteBuffer& bbuf);

            void init();

            void outputGridHeader(const DRegularGrid& grid, Internal::ByteBuffer& bbuf, std::size_t) const;

            bool writeRecordData(std::ostream& os) const;

            const Base::ControlParameterContainer& ctrlParams;
            Internal::ByteBuffer                   dataBuffer;
        };
    } // namespace Grid
} // namespace CDPL

#endif // CDPL_GRID_CDFREGULARGRIDDATAWRITER_HPP
